==> thrio-1.7.5.tar.gz: ios/Classes/Module/ThrioModuleJsonSerializer.m <==
// The MIT License (MIT)
//
// Copyright (c) 2020 foxsofter
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#import "ThrioModule.h"
#import "ThrioModuleJsonSerializer.h"
#import "ThrioNavigator+JsonSerializers.h"

NS_ASSUME_NONNULL_BEGIN

@implementation ThrioModule (JsonSerializer)

- (void)onJsonSerializerRegister {
}

- (ThrioVoidCallback)registerJsonSerializer:(id)serializer
                                   forClass:(id)clazz {
    return [ThrioNavigator.jsonSerializers registry:NSStringFromClass(clazz)
                                              value:serializer];
}

@end

NS_ASSUME_NONNULL_END

==> thrio-2.0.4.tar.gz: ios/Classes/Module/ThrioModuleJsonSerializer.m <==
// The MIT License (MIT)
//
// Copyright (c) 2020 foxsofter
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#import "ThrioModule.h"
#import "ThrioModuleJsonSerializer.h"
#import "ThrioModule+JsonSerializers.h"

NS_ASSUME_NONNULL_BEGIN

@implementation ThrioModule (JsonSerializer)

- (void)onJsonSerializerRegister:(ThrioModuleContext *)moduleContext {
}

- (ThrioVoidCallback)registerJsonSerializer:(id)serializer
                                   forClass:(id)clazz {
    return [ThrioModule.jsonSerializers registry:NSStringFromClass(clazz)
                                           value:serializer];
}

@end

NS_ASSUME_NONNULL_END
